@@ -11,6 +11,7 @@ class RecipeIngredient(mongo.EmbeddedDocument):
 class Recipe(mongo.Document):
     name = mongo.StringField(required=True)
     description = mongo.StringField()
+    preparation = mongo.StringField() #TODO will be a list of strings
     note = mongo.StringField()
     availabilityMonths = mongo.ListField(mongo.IntField(
         min_value=1, max_value=12), max_length=12, default=None)
@@ -19,7 +20,9 @@ class Recipe(mongo.Document):
     servs = mongo.IntField(min_value=1)
     estimatedCookingTime = mongo.IntField(min_value=1)
     estimatedPreparationTime = mongo.IntField(min_value=1)
-    rating = mongo.IntField(min_value=1, max_value=5)
+    rating = mongo.IntField(min_value=1, max_value=3)
+    cost = mongo.IntField(min_value=1, max_value=3)
+    difficulty = mongo.StringField()
     recipeUrl = mongo.StringField()
     tags = mongo.ListField(
         mongo.StringField(), default=None
